============
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

Bug reports
===========

When `reporting a bug <https://gitlab.com/ugognw/ase-stubs/-/issues>`_ please include:

    * Your operating system name and version.
    * Any details about your local setup that might be helpful in troubleshooting.
    * Detailed steps to reproduce the bug.

Development
===========

To set up `ase-stubs` for local development:

1. Fork `ase-stubs <https://gitlab.com/ugognw/ase-stubs/>`_
   (look for the "Fork" button).
2. Clone your fork locally::

    git clone git@gitlab.com:YOURGITLABNAME/ase-stubs.git

3. Create a branch for local development::

    git checkout -b name-of-your-bugfix-or-feature

   Now you can make your changes locally.

4. Commit your changes and push your branch to GitHub::

    git add .
    git commit -m "Your detailed description of your changes."
    git push origin name-of-your-bugfix-or-feature

5. Submit a merge request through the GitLab website.

Merge Request Guidelines
-----------------------

If you need some code review or feedback while you're developing the code just make a merge request.

For merging, you should:

1. Add a note to ``CHANGELOG.rst`` about the changes.
2. Add yourself to ``AUTHORS.rst``.
